@@ -404,7 +404,10 @@
 right click to fit to edges,
 double click or press Enter
 to take a screenshot.</source>
-        <translation type="unfinished"></translation>
+        <translation>Klicka och dra för a rita en rektangel
+högerklicka för att expandera till kanter
+dubbelklicka eller tryck Enter
+för att ta en skärmdump.</translation>
     </message>
     <message>
         <location filename="../src/core/regionselect.cpp" line="202"/>
@@ -600,12 +603,13 @@ to take a screenshot.</source>
         <location filename="../src/core/ui/configwidget.ui" line="407"/>
         <source>If this is unchecked, the selected area
 might become larger to fit to outer edges</source>
-        <translation type="unfinished"></translation>
+        <translation>Om detta är inaktiverat, kan markerat
+område bli större för att passa ytterkanterna</translation>
     </message>
     <message>
         <location filename="../src/core/ui/configwidget.ui" line="411"/>
         <source>Fit to edges inside selected area by right clicking</source>
-        <translation type="unfinished"></translation>
+        <translation>Anpassa till kanterna på insidan av markerat område med högerklick</translation>
     </message>
     <message>
         <location filename="../src/core/ui/configwidget.ui" line="449"/>
